@@ -1,8 +1,8 @@
 from infi.pyutils.lazy import cached_function
 from bunch import Bunch
 
-
-ASSIGNED_TO_ME = "assignee = currentUser() AND resolution = unresolved ORDER BY priority DESC, created ASC"
+CURRENT_USER = "currentUser()"
+ASSIGNED_ISSUES = "assignee = {} AND resolution = unresolved ORDER BY priority DESC, created ASC"
 
 
 @cached_function
@@ -15,8 +15,12 @@ def get_jira():
     return JIRA(options, basic_auth)
 
 
+def get_issues__assigned_to_user(user):
+    return get_jira().search_issues(ASSIGNED_ISSUES.format(user))
+
+
 def get_issues__assigned_to_me():
-    return get_jira().search_issues(ASSIGNED_TO_ME)
+    return get_issues__assigned_to_user(CURRENT_USER)
 
 
 def add_labels_to_issue(key, labels):
@@ -106,6 +110,10 @@ def search_issues(query):
     return jira.search_issues(query, maxResults=100)
 
 
+def comment_on_issue(key, message):
+    get_jira().add_comment(issue=key, body=message)
+
+
 @cached_function
 def get_issue(key):
     return get_jira().issue(key.upper())
